/*
 * $Id: WiretapSerialiserService.java 4289 2013-06-12 18:02:19Z mitcje $
 * $URL: https://open.jira.com/svn/IKASAN/tags/ikasaneip-0.9.0/wiretap/src/main/java/org/ikasan/wiretap/serialiser/WiretapSerialiserService.java $
 * 
 * ====================================================================
 * Ikasan Enterprise Integration Platform
 * 
 * Distributed under the Modified BSD License.
 * Copyright notice: The copyright for this software and a full listing 
 * of individual contributors are as shown in the packaged copyright.txt 
 * file. 
 * 
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without 
 * modification, are permitted provided that the following conditions are met:
 *
 *  - Redistributions of source code must retain the above copyright notice, 
 *    this list of conditions and the following disclaimer.
 *
 *  - Redistributions in binary form must reproduce the above copyright notice, 
 *    this list of conditions and the following disclaimer in the documentation 
 *    and/or other materials provided with the distribution.
 *
 *  - Neither the name of the ORGANIZATION nor the names of its contributors may
 *    be used to endorse or promote products derived from this software without 
 *    specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" 
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE 
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE 
 * DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE 
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL 
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR 
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER 
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE 
 * USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * ====================================================================
 */
package org.ikasan.wiretap.serialiser;

import java.util.Map;

import org.ikasan.spec.wiretap.WiretapSerialiser;

import org.apache.log4j.Logger;

/**
 * Implementation of the WiretapSerialiser factory.
 * 
 * @author Ikasan Development Team
 * 
 */
public class WiretapSerialiserService<SOURCE> implements WiretapSerialiser<SOURCE, String>
{
    private static Logger logger = Logger.getLogger(WiretapSerialiserService.class);

    private Map<Class<?>, WiretapSerialiser<?,String>> serialisers;

    public WiretapSerialiserService(Map<Class<?>, WiretapSerialiser<?,String>> serialisers)
    {
        this.serialisers = serialisers;
    }

    public String serialise(SOURCE source)
    {
        WiretapSerialiser<?,String> serialiser = this.serialisers.get(source.getClass());
        if (serialiser == null)
        {
            // TODO - there are some other options to try ie. readObject/writeObject
            
            // last resort - toString
            if(source instanceof byte[])
            {
                return new String( (byte[])source );
            }
            return source.toString();
        }

        return source.toString();
// FIXME        return serialiser.serialise(source);
    }
}
